import json
import os
import re
import urllib
from urllib.parse import urlparse

from dotenv import load_dotenv

from mycroft.common.logging import get_logger

LOGLEVEL = os.environ.get("LOGLEVEL", "WARNING").upper()
logger = get_logger(LOGLEVEL)

load_dotenv()

TIC_USER_KEY = os.getenv("TIC_KEY")
TIC_USER_SECRET = os.getenv("TIC_SECRET")


def get_es_urls():
    """
    Returns dict of env with its corresponding es_url including credentials.
    Example:
        {
            "dev01": "es_url1",
            "dev02": "es_url2
        }
    """
    # Expect JSON string for US prod and single string for others.
    # 1. US prod use 'multi_elasticsearch_json'
    # 2. Other stage/env use 'endpointUrlsJson'
    # 3. Fallback option is to use 'endpoint'
    cbd_es_url = os.getenv(
        "MULTI_CBD_ES_URL", os.getenv("CBD_ES_JSON_URL", os.getenv("CBD_ES_URL", ""))
    )
    logger.info(f"ES URL string: {cbd_es_url}")
    cbd_es_user = os.getenv("CBD_ES_USER", "")
    cbd_es_password = os.getenv("CBD_ES_PASSWORD", "")
    endpoints = {}
    try:
        data = json.loads(cbd_es_url)
        logger.info(f"[get_es_urls] JSON url: {cbd_es_url}")
        for env, value in data.items():
            if "clusterEndpoint" in value:
                endpoints[
                    env
                ] = f'http://{value["clusterEndpoint"]}:9200/a_orgrepoverride'
            else:
                parsed_url = urlparse(value[0])
                es_pass = urllib.parse.quote(cbd_es_password, safe="")
                endpoints[
                    env
                ] = f"{parsed_url.scheme}://{cbd_es_user}:{es_pass}@{parsed_url.hostname}:{parsed_url.port}/a_orgrepoverride"
    except json.JSONDecodeError:
        match = re.search(r"-(\w+)\.", cbd_es_url)
        if match:
            logger.info(f"[get_es_urls] Single tenant url: {cbd_es_url}")
            es_pass = urllib.parse.quote(cbd_es_password, safe="")
            es_url = (
                f"http://{cbd_es_user}:{es_pass}@{cbd_es_url}:9200/a_orgrepoverride"
            )
            endpoints[match.group(1)] = es_url
    return endpoints
