#!/usr/bin/env python
# coding: utf-8
import csv
import os

from mycroft.common.logging import get_logger

LOGLEVEL = os.environ.get("LOGLEVEL", "WARNING").upper()
logger = get_logger(LOGLEVEL)


def write_rules_to_csv(
    output_file_path, cached_matched_rules, env_org_policy, write_header
):
    if os.path.exists(output_file_path):
        append_write = "a"  # append if already exists
    else:
        append_write = "w"  # make a new file if not
    columns = [
        "recommendation_type",
        "value1",
        "value2",
        "value3",
        "env",
        "org_id",
        "policy_id",
        "dev_cnt",
        "org_cnt",
        "alert_cnt",
        "alert_dev_cnt",
        "comment1",
        "comment2",
        "impact_score",
    ]
    with open(output_file_path, append_write) as csvfile:
        recommendations = []
        for rule_path in cached_matched_rules:
            env = env_org_policy[0]
            org_id = env_org_policy[1]
            policy_id = env_org_policy[2]
            matched_rule = cached_matched_rules[rule_path]
            dev_cnt = matched_rule["dev_cnt"]
            alert_cnt = matched_rule["alert_cnt"]
            rule_sug = matched_rule["rule_sugg"]
            alert_dev_cnt = matched_rule["alert_dev_cnt"]
            for it in range(len(rule_sug)):
                rule_sug_arr = rule_sug[it].split(",")
                for r in range(len(rule_sug_arr)):
                    rule_sug_arr[r] = rule_sug_arr[r].strip('\n,"')
                action = ""
                if policy_id != "":
                    operation = rule_sug_arr[0]
                    action = rule_sug_arr[1]
                    org_cnt = int(rule_sug_arr[2])
                else:
                    org_cnt = int(rule_sug_arr[0])
                    operation = str(rule_sug_arr[1])
                logger.debug(
                    f"write rule to csv: rule_path: {rule_path}, operation: {operation}, action: {action}, env: {env}, org_id: {org_id}, policy_id: {policy_id}, dev_cnt: {dev_cnt}, alert_cnt: {alert_cnt}"
                )
                recommendation_type = "perm_rule" if policy_id != "" else "it_tools"
                recommendation = {
                    "recommendation_type": recommendation_type,
                    "value1": rule_path.replace("\\", "\\\\"),
                    "value2": operation,
                    "value3": action,
                    "env": env,
                    "org_id": org_id,
                    "policy_id": policy_id,
                    "dev_cnt": dev_cnt,
                    "org_cnt": org_cnt,
                    "alert_cnt": alert_cnt,
                    "alert_dev_cnt": alert_dev_cnt,
                    "comment1": "",
                    "comment2": "",
                    "impact_score": 0.0,
                }
                recommendations.append(recommendation)
        csvwriter = csv.DictWriter(csvfile, fieldnames=columns)
        if write_header:
            csvwriter.writeheader()
        csvwriter.writerows(recommendations)
